PhoneNumberValidatorInput class

Inheritance

Constructors

PhoneNumberValidatorInput({Key? key, double? height, bool? autoFocus, TextStyle? style, ValueChanged<String>? onChanged, int? maxLength, bool? isEnabled, TextAlign alignment = TextAlign.start, FocusNode? focusNode, String? validator(String?)?, bool isSecureText = false, String? suffixIconPath, VoidCallback? onSuffixIconPressed, Color? svgSuffixIconColor, Widget? suffixIconWidget, Color fillColor = Colors.transparent, InputBorder? border, TextStyle? hintStyle, VoidCallback? onTap, required TextEditingController controller, String? emptyFieldErrorMessage, String? inValidPhoneNumberErrorMessage, String? inValidEmailErrorMessage, String? inValidLengthErrorMessage, String? labelText, TextStyle? labelStyle, TextStyle? errorStyle, double? margin, bool canAcceptEmail = false, bool? readOnly, TextCapitalization textCapitalization = TextCapitalization.none, String? hintText, int? minLines})
const

Properties

alignment TextAlign
final
autoFocus bool?
final
border InputBorder?
final
canAcceptEmail bool
final
controller TextEditingController
final
emptyFieldErrorMessage String?
final
errorStyle TextStyle?
final
fillColor Color
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
hintStyle TextStyle?
final
hintText String?
final
inValidEmailErrorMessage String?
final
inValidLengthErrorMessage String?
final
inValidPhoneNumberErrorMessage String?
final
isEnabled bool?
final
isSecureText bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
labelText String?
final
margin double?
final
maxLength int?
final
minLines int?
final
onChanged ValueChanged<String>?
final
onSuffixIconPressed VoidCallback?
final
onTap VoidCallback?
final
readOnly bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
final
suffixIconPath String?
final
suffixIconWidget Widget?
final
svgSuffixIconColor Color?
final
textCapitalization TextCapitalization
final
type TextInputType
final
validator String? Function(String?)?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited