Utils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- emailValidation ↔ RegExp
-
getter/setter pair
- onlyDigitsValidation ↔ RegExp
-
getter/setter pair
- phoneNumberValidation ↔ RegExp
-
getter/setter pair
Static Methods
-
isNormal(
BuildContext context) → bool -
isSmall(
BuildContext context) → bool -
isTablet(
BuildContext context) → bool -
validateEmpty(
{String? value, String? errorMessage}) → String?
Constants
- smallDeviceSize → const Size
- tabletDeviceSize → const Size